==> haskell-cheapskate-0.1.1.2-719-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-6gPYeUDp125LlqTvtywxw3
key:                  cheapskate-0.1.1.2-6gPYeUDp125LlqTvtywxw3
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  cb2e894a5c7ee9a09c80af46fc45355d
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-6gPYeUDp125LlqTvtywxw3
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-FKwarBKbyvpIFQ2PEdKkVd
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.2.4-7bSc04XXCdy5oWDf8UOHZs
    text-2.0.2 uniplate-1.6.13-3t4NeuKPUknBzYHBQ5ITf
    xss-sanitize-0.3.7.2-3dXWP2uQHFVLkhNywEWGkW

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.2-730-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-1g0jxxdBvqbzRMR9C8TeB
key:                  cheapskate-0.1.1.2-1g0jxxdBvqbzRMR9C8TeB
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  e1327f594ec74ba1177799813495983d
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-1g0jxxdBvqbzRMR9C8TeB
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-7rraM1lSLOl2LrVAS4qxq6
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb
    text-2.0.2 uniplate-1.6.13-GITJjIsFrN3LhT62nm4yCi
    xss-sanitize-0.3.7.2-4LpGnsWDAd25pdzsNeAUaZ

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
